@@ -55,9 +55,6 @@ mc3 <- function(ac, wr = FALSE) {
 
   stime <- Sys.time()
 
-  ## Force all concentrations to 1 significant figure
-  dat[ , conc := signif(conc, 1)]
-
   ## Load aeid mapping information.
   aeid_info <- tcplLoadAeid("acid", ac)[ , list(acid, aeid)]
   setkey(aeid_info, acid)
