@@ -65,6 +65,7 @@
 #'   \item{pc20}{Add a cutoff value of 20. Typically for percent of control data.}
 #'   \item{pc25}{Add a cutoff value of 25. Typically for percent of control data.}
 #'   \item{pc30}{Add a cutoff value of 30. Typically for percent of control data.}
+#'   \item{pc40}{Add a cutoff value of 40. Typically for percent of control data.}
 #'  }
 #' }
 #' 
@@ -251,6 +252,13 @@ sc2_mthds <- function() {
       e1 <- bquote(coff <- c(coff, 16))
       list(e1)
       
+    },
+
+    pc40 = function() {
+      
+      e1 <- bquote(coff <- c(coff, 40))
+      list(e1)
+      
     }
   )
 }
