@@ -14,12 +14,11 @@ tcplConfReset <- function () {
       "## Detailed information about this file available in the help file for",
       "## tcplConf (?tcplConf).",
       "",
-      "DRVR <- \"tcplLite\"",
+      "DRVR <- \"API\"",
       "HOST <- NA_character_",
       "USER <- NA_character_",
-      "PASS <- NA_character_",
-      "DB   <- file.path(system.file(package = \"tcpl\"),",
-      "                  \"csv\")",
+      "PASS <- \"01cbaf22-904f-11ee-954e-325096b39f47\"",
+      "DB   <- NA_character_",
       "",
       "###################################################################",
       sep = "\n",
