@@ -14,8 +14,10 @@
 #' tcplLoad- functions.
 #' 
 #' @examples 
+#' \dontrun{
 #' ## Gives the fields in the mc1 table
 #' tcplListFlds("mc1")
+#' }
 #' 
 #' @return A string of field names for the given table.
 #' 
@@ -28,6 +30,9 @@ tcplListFlds <- function(tbl, db = getOption("TCPL_DB")) {
   ## Variable-binding to pass R CMD Check
   name <- COLUMN_NAME <- NULL
   
+  if (getOption("TCPL_DRVR") == "API")  {
+    stop("'API' driver not supported in tcplListFlds.")
+  }
   if (length(tbl) > 1 | length(db) > 1) {
     stop("tbl and db must both be of length 1.")  
   } 
@@ -51,16 +56,6 @@ tcplListFlds <- function(tbl, db = getOption("TCPL_DB")) {
     
   }
   
-  if (getOption("TCPL_DRVR") == "tcplLite")  {
-    # return the data table by reading the file. No need to run tcplQuery, simply return data.table columns here
-    fpath <- paste(db, tbl, sep='/')
-    fpath <- paste(fpath, 'csv', sep='.')
-    DT <- read.table(fpath, header=T, sep=',', fill=T)
-    return(colnames(DT))
-
-    
-  }
-  
   stop(getOption("TCPL_DRVR"), " is not a supported database system. See ",
        "?tcplConf for more details.")
   
