@@ -17,6 +17,9 @@ tcplQuery <- function(query, db = getOption("TCPL_DB"),
   if (is.null(drvr)) drvr <- getOption("TCPL_DRVR")
   
   #Check for valid inputs
+  if (drvr == "API") {
+    stop("'API' driver not supported in tcplQuery.")
+  }
   if (length(query) != 1 || !is(query, "character")) {
     stop("The input 'query' must be a character of length one.")
   }
@@ -45,20 +48,6 @@ tcplQuery <- function(query, db = getOption("TCPL_DB"),
     
   }
   
-  if (drvr == "tcplLite") {
-    #query <- "SELECT spid,chemical.chid,casn,chnm FROM sample LEFT JOIN chemical ON chemical.chid=sample.chid WHERE sample.chid is NULL  "
-    db_pars <- "Just running tcplLite, we're OK"
-    for (t in tbl) {
-      fpath <- paste(db, t, sep='/')
-      fpath <- paste(fpath, 'csv', sep='.')
-      assign(t, read.table(fpath, header=T, sep=','))
-    }
-
-    result <- as.data.table(sqldf(query, stringsAsFactors=F))
-
-    
-  }
-  
   if (is.null(db_pars)) {
     
     stop(getOption("TCPL_DRVR"), " is not a supported database system. See ",
@@ -67,6 +56,11 @@ tcplQuery <- function(query, db = getOption("TCPL_DB"),
   }
   
   if (drvr == 'MySQL') {
+    
+    if("RMySQL" %in% loadedNamespaces()){
+      unloadNamespace("RMySQL")
+      warning("'RMySQL' package is not supported with tcpl and has been detached.")
+    }
     dbcon <- do.call(dbConnect, db_pars)
     result <- dbGetQuery(dbcon, query)
     
